searchNodes=[{"doc":"Documentation for Liberator.","ref":"Liberator.html","title":"Liberator","type":"module"},{"doc":"A controller module that understands and respects the HTTP spec.This module implements a Plug handler that allows an endpoint to comply to the HTTP specification, and to do so by just answering a few questions.Define a simple resource like this:defmodule MyFirstResource do use Liberator.Resource def available_media_types(_), do: [&quot;text/plain&quot;] def handle_ok(_), do: &quot;Hello world!&quot; endTo add this plug to a Phoenix application, use the Phoenix.Router.forward/4 keyword in your router:scope &quot;/&quot;, MyApp do pipe_through [:browser] forward &quot;/api/resource&quot;, MyFirstResource endIf you're using another Plug-based framework, use Plug.forward/4 once you've matched on the path:defmodule Router do def init(opts), do: opts def call(conn, opts) do case conn do %{host: &quot;localhost&quot;, path_info: [&quot;resources&quot; | rest]} -&gt; Plug.forward(conn, rest, MyFirstResource, opts) _ -&gt; MainRouter.call(conn, opts) end end endThere are lots of decisions to be made during content negotiation, and Liberator lets gives you access to every single one, but it's also built with sensible defaults that let you quickly build up a controller.Content NegotiationThese functions return lists of available values during content negotiation. If the client has an accept header that does not match a value from these lists, the plug will return a 406 Not Acceptable response, and call handle_not_acceptable/1.FunctionDefaultallowed_methods/1[&quot;GET&quot;, &quot;HEAD&quot;]known_methods/1[&quot;GET&quot;, &quot;HEAD&quot;, &quot;OPTIONS&quot;, &quot;PUT&quot;, &quot;POST&quot;, &quot;DELETE&quot;, &quot;PATCH&quot;, &quot;TRACE&quot;]available_media_types/1[]available_languages/1[&quot;*&quot;]available_charsets/1[&quot;UTF-8&quot;]available_encodings/1[&quot;identity&quot;]PreconditionsThese functions decide the state of preconditon decisions for the request. Depending on the specific method and request headers, the plug may return a 412 Precondition Failed response, a 304 Not Modified response, or may allow another kind of request to continue.FunctionDefaultlast_modified/1DateTime.utc_now()etag/1nilActionsActions make the necessary changes to the requested entity.FunctionDescriptioninitialize/1Performs any custom initialization you need before the decision tree startsdelete!/1Called for DELETE requestspatch!/1Called for PATCH requestspost!/1Called for POST requestsput!/1Called for PUT requestsHandlersHandlers are called at the very end of the decision tree, and allow you to return content for rendering to the client.FunctionStatushandle_ok/1200handle_options/1200handle_created/1201handle_accepted/1202handle_no_content/1204handle_multiple_representations/1300handle_moved_permanently/1301handle_see_other/1303handle_not_modified/1304handle_moved_temporarily/1307handle_malformed/1400handle_unauthorized/1401handle_forbidden/1403handle_not_found/1404handle_method_not_allowed/1405handle_not_acceptable/1406handle_conflict/1409handle_gone/1410handle_precondition_failed/1412handle_request_entity_too_large/1413handle_uri_too_long/1414handle_unsupported_media_type/1415handle_unprocessable_entity/1422handle_unknown_method/1501handle_not_implemented/1501handle_service_unavailable/1503DecisionsLiberator supports a whole lot of decisions points. Some of them are needed for next to every resource definition. Others are seldom used or there is no other sensible implementation.Return any truthy value for a true response. If you return a map, Liberator will merge that map with the conn's :assigns map, allowing you to cache data and do work when it makes sense. For example, the exists?/1 callback is a great place to fetch your resource, and you can return it as a map for your later functions to act upon.FunctionDescriptionDefaultallowed?/1Is the user allowed to make this request?trueauthorized?/1Is necessary authentication information present?truecharset_available?/1Are any of the requested charsets available? Should assign the :charset variable.Uses values at available_charsets/1can_post_to_gone?/1Should we process a POST to a resource that previously existed?falsecan_post_to_missing?/1Should we process a POST to a resource that does not exist?truecan_put_to_missing?/1Should we process a PUT to a resource that does not exist?trueconflict?/1Does the PUT or POST request result in a conflict?falsedelete_enacted?/1Was the delete request finally processed?trueencoding_available?/1Is the requested encoding available? Should assign the :encoding variable.Uses values at available_encodings/1etag_matches_for_if_match?/1Does the etag of the current resource match the If-Match header?Uses value generated by etag/1etag_matches_for_if_none?/1Does the etag of the current resource match the If-None-Match header?Uses value generated by etag/1existed?/1Did the resource exist before?falseexists?/1Does the resource exist?trueknown_content_type?/1Is the Content-Type of the body known?trueknown_method?/1Is the request method known?Uses values at known_methods/1language_available?/1Is the requested language available? Should assign the :language variable.Uses values at available_languages/1malformed?/1Is the request malformed?falsemedia_type_available?/1Is the requested media type available? Should assign the :media_type variale.Uses values at available_media_types/1method_allowed?/1Is the request method allowed for this resource?Uses values at allowed_methods/1modified_since?/1Was the resource modified since the date given in the If-Modified-Since header?Uses value generated by last_modified/1moved_permanently?/1Was the resource moved permanently?falsemoved_temporarily?/1Was the resource moved temporarily?falsemultiple_representations?/1Are there multiple representations for this resource?falsepost_enacted?/1Was the POST request finally processed?trueput_enacted?/1Was the PUT request finally processed?truepatch_enacted?/1Was the PATCH request finally processed?truenew?/1Was the resource created by this request?truepost_redirect?/1Should the response redirect after a POST?falseput_to_different_url?/1Should the PUT request be made to a different URL?falseprocessable?/1Is the request body processable?trueservice_available?/1Is the service available?trueuri_too_long?/1Is the request URI too long?falsevalid_content_header?/1Is the Content-Type of the body valid?truevalid_entity_length?/1Is the length of the body valid?trueInternal Decision PointsThese decision points are used internally by Liberator and provide reasonable defaults. Overriding is possible, but not useful in general.FunctionDescriptionaccept_charset_exists?/1Checks if header Accept-Charset exists.accept_encoding_exists?/1Checks if header Accept-Encoding exists.accept_exists?/1Checks if header Accept exists.accept_language_exists?/1Checks if header Accept-Language exists.if_match_exists?/1Checks if header If-Match exists.if_match_star?/1Checks if header If-Match is *.if_match_star_exists_for_missing?/1Checks if header If-Match exists for a resource that does not exist.c:if_modified_since?/1Checks if header If-Modified-Since exists.c:if_modified_valid_date?/1Checks if header If-Modified-Since is a valid HTTP date.if_none_match?/1Checks if the request method to handle failed If-None-Matchif_none_match_exists?/1Checks if header If-None-Match exists.if_none_match_star?/1Checks if header If-None-Match is *.if_unmodified_since_exists?/1Checks if header If-Unmodified-Since exists.c:if_unmodified_valid_date?/1Checks if header If-Unmodified-Since is a valid HTTP date.is_options?/1Checks if the request method is OPTIONSmethod_delete?/1Checks if the request method is DELETEmethod_put?/1Checks if the request method is PUTmethod_patch?/1Checks if the request method is PATCHpost_to_gone?/1Checks if the request method is POST for resources that do not exist anymore.post_to_existing?/1Checks if the request method is POST for resources that do exist.post_to_missing?/1Checks if the request method is POST for resources that do not exist.put_to_existing?/1Checks if the request method is PUT for a resource that exists.","ref":"Liberator.Resource.html","title":"Liberator.Resource","type":"behaviour"},{"doc":"Check if the Accept-Charset header exists.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:accept_charset_exists?/1","title":"Liberator.Resource.accept_charset_exists?/1","type":"callback"},{"doc":"Check if the Accept-Encoding header exists.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:accept_encoding_exists?/1","title":"Liberator.Resource.accept_encoding_exists?/1","type":"callback"},{"doc":"Check if the Accept header exists.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:accept_exists?/1","title":"Liberator.Resource.accept_exists?/1","type":"callback"},{"doc":"Check if the Accept-Language header exists.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:accept_language_exists?/1","title":"Liberator.Resource.accept_language_exists?/1","type":"callback"},{"doc":"Check the authentication information in the request to see if it has the necessary permissions.Note the difference between authorized?/1 and allowed?/1. This function checks if the given request is allowed to perform an action, but isn't responsible for checking the presence of authentication information in the first place.By default, always returns true.","ref":"Liberator.Resource.html#c:allowed?/1","title":"Liberator.Resource.allowed?/1","type":"callback"},{"doc":"Returns a list of HTTP methods that this module serves.The methods returned by this function should be upper-case strings, like &quot;GET&quot;, &quot;POST&quot;, etc.","ref":"Liberator.Resource.html#c:allowed_methods/1","title":"Liberator.Resource.allowed_methods/1","type":"callback"},{"doc":"Check for presence ofauthentication information in the request.Note the difference between authorized?/1 and allowed?/1. This function should just check for the presence of authentication information, not the content of it.If you implement this function to return false, your response in handle_unauthorized must include a WWW-Authenticate header field containing a challenge applicable to the requested resource.By default, always returns true.","ref":"Liberator.Resource.html#c:authorized?/1","title":"Liberator.Resource.authorized?/1","type":"callback"},{"doc":"Returns a list of available content charsets.By default, only UTF-8 is supported.","ref":"Liberator.Resource.html#c:available_charsets/1","title":"Liberator.Resource.available_charsets/1","type":"callback"},{"doc":"Returns a list of available response content encodings (AKA compressions).By default, only identity (no compression) is supported.","ref":"Liberator.Resource.html#c:available_encodings/1","title":"Liberator.Resource.available_encodings/1","type":"callback"},{"doc":"Returns a list of available languages.","ref":"Liberator.Resource.html#c:available_languages/1","title":"Liberator.Resource.available_languages/1","type":"callback"},{"doc":"Returns a list of content types that this module serves.The types returned by this function should be valid MIME types, like text/plain, application/json, etc.","ref":"Liberator.Resource.html#c:available_media_types/1","title":"Liberator.Resource.available_media_types/1","type":"callback"},{"doc":"Callback implementation for Plug.call/2.","ref":"Liberator.Resource.html#call/2","title":"Liberator.Resource.call/2","type":"function"},{"doc":"Decide if we can process a POST to a resource that existed before, or return a 410 Gone response.By default, always returns false.","ref":"Liberator.Resource.html#c:can_post_to_gone?/1","title":"Liberator.Resource.can_post_to_gone?/1","type":"callback"},{"doc":"Check if we can process a post to a resource that does not exist, or if we should send a 404 Not Found response.By default, always returns true.","ref":"Liberator.Resource.html#c:can_post_to_missing?/1","title":"Liberator.Resource.can_post_to_missing?/1","type":"callback"},{"doc":"Decide if we can PUT to a resource that does not exist, or return 501 Not Implemented.By default, always returns true.","ref":"Liberator.Resource.html#c:can_put_to_missing?/1","title":"Liberator.Resource.can_put_to_missing?/1","type":"callback"},{"doc":"Check of the requested charset is available.By default, uses the values returned by available_charsets/1.","ref":"Liberator.Resource.html#c:charset_available?/1","title":"Liberator.Resource.charset_available?/1","type":"callback"},{"doc":"Does the PUT or POST request result in a conflict?","ref":"Liberator.Resource.html#c:conflict?/1","title":"Liberator.Resource.conflict?/1","type":"callback"},{"doc":"Called for DELETE requests.","ref":"Liberator.Resource.html#c:delete!/1","title":"Liberator.Resource.delete!/1","type":"callback"},{"doc":"Check if the DELETE request was processed. Return false here if the request was put on some processing queue and the delete was not actually enacted yet. Returning false here would return a 202 Accepted instead of some other response.By default, always returns true.","ref":"Liberator.Resource.html#c:delete_enacted?/1","title":"Liberator.Resource.delete_enacted?/1","type":"callback"},{"doc":"Check of the requested encoding is available.By default, uses the values returned by available_encodings/1.","ref":"Liberator.Resource.html#c:encoding_available?/1","title":"Liberator.Resource.encoding_available?/1","type":"callback"},{"doc":"Returns the etag for the current entity.This value will be used to respond to caching headers like If-None-Match.","ref":"Liberator.Resource.html#c:etag/1","title":"Liberator.Resource.etag/1","type":"callback"},{"doc":"Check if the etag for the current resource matches the value in the If-Match header.By default, checks the header against the value returned by etag/1.","ref":"Liberator.Resource.html#c:etag_matches_for_if_match?/1","title":"Liberator.Resource.etag_matches_for_if_match?/1","type":"callback"},{"doc":"Check if the etag of the current resource matches the If-Match-None header.By default, checks the header against the value returned by etag/1.","ref":"Liberator.Resource.html#c:etag_matches_for_if_none?/1","title":"Liberator.Resource.etag_matches_for_if_none?/1","type":"callback"},{"doc":"Check if the resource ever existed.Answering true here will lead you down the path that leads to responses like &quot;Moved Permanently&quot; and &quot;Gone&quot;, among othes.","ref":"Liberator.Resource.html#c:existed?/1","title":"Liberator.Resource.existed?/1","type":"callback"},{"doc":"Check if the requested entity exists.This is a great place to actually fetch the requested resource, then return it as a map so it can be merged into the :assigns map of the request.Returning false here will cause the plug to return a 404 Not Found response.","ref":"Liberator.Resource.html#c:exists?/1","title":"Liberator.Resource.exists?/1","type":"callback"},{"doc":"Returns content for a 202 Accepted response.","ref":"Liberator.Resource.html#c:handle_accepted/1","title":"Liberator.Resource.handle_accepted/1","type":"callback"},{"doc":"Returns content for a 409 Conflict response.","ref":"Liberator.Resource.html#c:handle_conflict/1","title":"Liberator.Resource.handle_conflict/1","type":"callback"},{"doc":"Returns content for a 201 Created response.","ref":"Liberator.Resource.html#c:handle_created/1","title":"Liberator.Resource.handle_created/1","type":"callback"},{"doc":"Returns content for a 403 Forbidden response.","ref":"Liberator.Resource.html#c:handle_forbidden/1","title":"Liberator.Resource.handle_forbidden/1","type":"callback"},{"doc":"Returns content for a 410 Gone response.","ref":"Liberator.Resource.html#c:handle_gone/1","title":"Liberator.Resource.handle_gone/1","type":"callback"},{"doc":"Returns content for a 400 Malformed response.","ref":"Liberator.Resource.html#c:handle_malformed/1","title":"Liberator.Resource.handle_malformed/1","type":"callback"},{"doc":"Returns content for a 405 Method Not Allowed response.","ref":"Liberator.Resource.html#c:handle_method_not_allowed/1","title":"Liberator.Resource.handle_method_not_allowed/1","type":"callback"},{"doc":"Returns content for a 301 Moved Permanently response.","ref":"Liberator.Resource.html#c:handle_moved_permanently/1","title":"Liberator.Resource.handle_moved_permanently/1","type":"callback"},{"doc":"Returns content for a 307 Moved Permanently response.","ref":"Liberator.Resource.html#c:handle_moved_temporarily/1","title":"Liberator.Resource.handle_moved_temporarily/1","type":"callback"},{"doc":"Returns content for a 300 Multiple Representations response.","ref":"Liberator.Resource.html#c:handle_multiple_representations/1","title":"Liberator.Resource.handle_multiple_representations/1","type":"callback"},{"doc":"Returns content for a 204 No Content response.","ref":"Liberator.Resource.html#c:handle_no_content/1","title":"Liberator.Resource.handle_no_content/1","type":"callback"},{"doc":"Returns content for a 406 Not Acceptable response.","ref":"Liberator.Resource.html#c:handle_not_acceptable/1","title":"Liberator.Resource.handle_not_acceptable/1","type":"callback"},{"doc":"Returns content for a 404 Not Found response.","ref":"Liberator.Resource.html#c:handle_not_found/1","title":"Liberator.Resource.handle_not_found/1","type":"callback"},{"doc":"Returns content for a 501 Not Implemented response.","ref":"Liberator.Resource.html#c:handle_not_implemented/1","title":"Liberator.Resource.handle_not_implemented/1","type":"callback"},{"doc":"Returns content for a 304 Not Modified response.","ref":"Liberator.Resource.html#c:handle_not_modified/1","title":"Liberator.Resource.handle_not_modified/1","type":"callback"},{"doc":"Returns content for a 200 OK response.","ref":"Liberator.Resource.html#c:handle_ok/1","title":"Liberator.Resource.handle_ok/1","type":"callback"},{"doc":"Returns content for a 200 OK response to an OPTIONS request.","ref":"Liberator.Resource.html#c:handle_options/1","title":"Liberator.Resource.handle_options/1","type":"callback"},{"doc":"Returns content for a 412 Precondition Failed response.","ref":"Liberator.Resource.html#c:handle_precondition_failed/1","title":"Liberator.Resource.handle_precondition_failed/1","type":"callback"},{"doc":"Returns content for a 413 Entity Too Large response.","ref":"Liberator.Resource.html#c:handle_request_entity_too_large/1","title":"Liberator.Resource.handle_request_entity_too_large/1","type":"callback"},{"doc":"Returns content for a 303 See Other response.","ref":"Liberator.Resource.html#c:handle_see_other/1","title":"Liberator.Resource.handle_see_other/1","type":"callback"},{"doc":"Returns content for a 503 Service Unavailable response.","ref":"Liberator.Resource.html#c:handle_service_unavailable/1","title":"Liberator.Resource.handle_service_unavailable/1","type":"callback"},{"doc":"Returns content for a 401 Unauthorized response.","ref":"Liberator.Resource.html#c:handle_unauthorized/1","title":"Liberator.Resource.handle_unauthorized/1","type":"callback"},{"doc":"Returns content for a 501 Unknown Method response.","ref":"Liberator.Resource.html#c:handle_unknown_method/1","title":"Liberator.Resource.handle_unknown_method/1","type":"callback"},{"doc":"Returns content for a 422 Unprocesable Entity response.","ref":"Liberator.Resource.html#c:handle_unprocessable_entity/1","title":"Liberator.Resource.handle_unprocessable_entity/1","type":"callback"},{"doc":"Returns content for a 415 Unsuppported Media Type response.","ref":"Liberator.Resource.html#c:handle_unsupported_media_type/1","title":"Liberator.Resource.handle_unsupported_media_type/1","type":"callback"},{"doc":"Returns content for a 414 URI Too Long response.","ref":"Liberator.Resource.html#c:handle_uri_too_long/1","title":"Liberator.Resource.handle_uri_too_long/1","type":"callback"},{"doc":"Check if the If-Match header exists.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:if_match_exists?/1","title":"Liberator.Resource.if_match_exists?/1","type":"callback"},{"doc":"Check if the If-Match header is *.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:if_match_star?/1","title":"Liberator.Resource.if_match_star?/1","type":"callback"},{"doc":"Check if the If-Match * header exists for a resource that does not exist.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:if_match_star_exists_for_missing?/1","title":"Liberator.Resource.if_match_star_exists_for_missing?/1","type":"callback"},{"doc":"Check if the If-Modified-Since header exists.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:if_modified_since_exists?/1","title":"Liberator.Resource.if_modified_since_exists?/1","type":"callback"},{"doc":"Check if the If-Modified-Since header is a valid HTTP date.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:if_modified_since_valid_date?/1","title":"Liberator.Resource.if_modified_since_valid_date?/1","type":"callback"},{"doc":"Check if the request method to handle failed if-none-match.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:if_none_match?/1","title":"Liberator.Resource.if_none_match?/1","type":"callback"},{"doc":"Check if the If-None-Match header exists.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:if_none_match_exists?/1","title":"Liberator.Resource.if_none_match_exists?/1","type":"callback"},{"doc":"Check if the If-None-Match header is *.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:if_none_match_star?/1","title":"Liberator.Resource.if_none_match_star?/1","type":"callback"},{"doc":"Check if the If-Unmodified-Since header exists.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:if_unmodified_since_exists?/1","title":"Liberator.Resource.if_unmodified_since_exists?/1","type":"callback"},{"doc":"Check if the If-Unmodified-Since header is a valid HTTP date.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:if_unmodified_since_valid_date?/1","title":"Liberator.Resource.if_unmodified_since_valid_date?/1","type":"callback"},{"doc":"Callback implementation for Plug.init/1.","ref":"Liberator.Resource.html#init/1","title":"Liberator.Resource.init/1","type":"function"},{"doc":"A hook invoked at the beginning of the decision tree to set up anything you may need.You can return a map here and it will be merged with the given conn's :assigns map.","ref":"Liberator.Resource.html#c:initialize/1","title":"Liberator.Resource.initialize/1","type":"callback"},{"doc":"Check if the request method is Options.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:is_options?/1","title":"Liberator.Resource.is_options?/1","type":"callback"},{"doc":"Check if the Content-Type of the body is known.By default, always returns true.","ref":"Liberator.Resource.html#c:known_content_type?/1","title":"Liberator.Resource.known_content_type?/1","type":"callback"},{"doc":"Check of the HTTP method in the request is one we know about.This is different from allowed_methods/1 in that this function checks to see if the given HTTP method is an HTTP method at all. You probably want to override allowed_methods/1 and not this one, unless you're extending HTTP with more verbs.If this function returns false, then the plug will return a 501 Unknown Method response.By default, allows the methods returned by known_methods/1.","ref":"Liberator.Resource.html#c:known_method?/1","title":"Liberator.Resource.known_method?/1","type":"callback"},{"doc":"Returns a list of HTTP methods that exist.Note that this is to filter bad HTTP requests, not to filter requests that your endpoint does not serve. You probably want to implement allowed_methods/1 instead.The methods returned by this function should be upper-case strings, like &quot;GET&quot;, &quot;POST&quot;, etc.","ref":"Liberator.Resource.html#c:known_methods/1","title":"Liberator.Resource.known_methods/1","type":"callback"},{"doc":"Check if the requested language is available.By default, uses the values returned by available_languages/1.","ref":"Liberator.Resource.html#c:language_available?/1","title":"Liberator.Resource.language_available?/1","type":"callback"},{"doc":"Returns the last modified date of your resource.This value will be used to respond to caching headers like If-Modified-Since.","ref":"Liberator.Resource.html#c:last_modified/1","title":"Liberator.Resource.last_modified/1","type":"callback"},{"doc":"Check the request for general adherence to some form.If this function returns false, then the plug will return a 400 Malformed response.If you're checking the body of a request against some schema, you should override processable?/1 instead.By default, always returns false.","ref":"Liberator.Resource.html#c:malformed?/1","title":"Liberator.Resource.malformed?/1","type":"callback"},{"doc":"Check if the request media type is available.By default, uses the values returned by available_media_types/1.","ref":"Liberator.Resource.html#c:media_type_available?/1","title":"Liberator.Resource.media_type_available?/1","type":"callback"},{"doc":"Check if the server supports the request's HTTP method.Override allowed_methods/1 instead of this function to let this plug perform the check for you.By default, allows the methods returned by allowed_methods/1.","ref":"Liberator.Resource.html#c:method_allowed?/1","title":"Liberator.Resource.method_allowed?/1","type":"callback"},{"doc":"Check if the request method is DELETE.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:method_delete?/1","title":"Liberator.Resource.method_delete?/1","type":"callback"},{"doc":"Check if the request method is PATCH.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:method_patch?/1","title":"Liberator.Resource.method_patch?/1","type":"callback"},{"doc":"Check if the request method is POST.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:method_post?/1","title":"Liberator.Resource.method_post?/1","type":"callback"},{"doc":"Check if the request method is PUT.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:method_put?/1","title":"Liberator.Resource.method_put?/1","type":"callback"},{"doc":"Checks if the resource was modified since the date given in the If-Modified-Since header.By default, checks the header against the value returned by last_modified/1.","ref":"Liberator.Resource.html#c:modified_since?/1","title":"Liberator.Resource.modified_since?/1","type":"callback"},{"doc":"Check if the resource was moved permanently.By default, always returns false.","ref":"Liberator.Resource.html#c:moved_permanently?/1","title":"Liberator.Resource.moved_permanently?/1","type":"callback"},{"doc":"Check if the resource was moved temporarily.By default, always returns false.","ref":"Liberator.Resource.html#c:moved_temporarily?/1","title":"Liberator.Resource.moved_temporarily?/1","type":"callback"},{"doc":"Check if there are multiple representations of the resource.","ref":"Liberator.Resource.html#c:multiple_representations?/1","title":"Liberator.Resource.multiple_representations?/1","type":"callback"},{"doc":"Was the resource created by this request?","ref":"Liberator.Resource.html#c:new?/1","title":"Liberator.Resource.new?/1","type":"callback"},{"doc":"Called for PATCH requests.","ref":"Liberator.Resource.html#c:patch!/1","title":"Liberator.Resource.patch!/1","type":"callback"},{"doc":"Check if the PATCH request was processed. Return false here if the request was put on some processing queue and the patch was not actually enacted yet. Returning false here would return a 202 Accepted instead of some other response.By default, always returns true.","ref":"Liberator.Resource.html#c:patch_enacted?/1","title":"Liberator.Resource.patch_enacted?/1","type":"callback"},{"doc":"Called for POST requests.","ref":"Liberator.Resource.html#c:post!/1","title":"Liberator.Resource.post!/1","type":"callback"},{"doc":"Check if the POST request was processed. Return false here if the request was put on some processing queue and the post was not actually enacted yet. Returning false here would return a 202 Accepted instead of some other response.By default, always returns true.","ref":"Liberator.Resource.html#c:post_enacted?/1","title":"Liberator.Resource.post_enacted?/1","type":"callback"},{"doc":"Decide if the response should redirect after a POST.By default, always returns false.","ref":"Liberator.Resource.html#c:post_redirect?/1","title":"Liberator.Resource.post_redirect?/1","type":"callback"},{"doc":"Check if the request method is POST for a resource that already exists.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:post_to_existing?/1","title":"Liberator.Resource.post_to_existing?/1","type":"callback"},{"doc":"Check if the request method is POST for resources that do not exist anymore.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:post_to_gone?/1","title":"Liberator.Resource.post_to_gone?/1","type":"callback"},{"doc":"Check if the request method is POST to a resource that doesn't exist.Used internally; it is not advised to override this function.","ref":"Liberator.Resource.html#c:post_to_missing?/1","title":"Liberator.Resource.post_to_missing?/1","type":"callback"},{"doc":"Check if the body of the request can be processed.This is a good place to parse a JSON body if that's what you're doing. Returning false here would cause the plug to return a 422 Unprocessable response.","ref":"Liberator.Resource.html#c:processable?/1","title":"Liberator.Resource.processable?/1","type":"callback"},{"doc":"Called for PUT requests.","ref":"Liberator.Resource.html#c:put!/1","title":"Liberator.Resource.put!/1","type":"callback"},{"doc":"Check if the PUT request was processed. Return false here if the request was put on some processing queue and the put was not actually enacted yet. Returning false here would return a 202 Accepted instead of some other response.By default, always returns true.","ref":"Liberator.Resource.html#c:put_enacted?/1","title":"Liberator.Resource.put_enacted?/1","type":"callback"},{"doc":"Decide if a PUT request should be made to a different URL.By default, always returns false.","ref":"Liberator.Resource.html#c:put_to_different_url?/1","title":"Liberator.Resource.put_to_different_url?/1","type":"callback"},{"doc":"Check if the request method is a PUT for a resource that already exists.","ref":"Liberator.Resource.html#c:put_to_existing?/1","title":"Liberator.Resource.put_to_existing?/1","type":"callback"},{"doc":"Should the response contain a representation of the resource?","ref":"Liberator.Resource.html#c:respond_with_entity?/1","title":"Liberator.Resource.respond_with_entity?/1","type":"callback"},{"doc":"Check if your service is available.This is the first function called in the entire pipeline, and lets you check to make sure everything works before going deeper. If this function returns false, then the plug will return a 503 Service Not Available response.By default, always returns true.","ref":"Liberator.Resource.html#c:service_available?/1","title":"Liberator.Resource.service_available?/1","type":"callback"},{"doc":"Checks if the resource was not modified since the date given in the If-Unmodified-Since header.By default, checks the header against the value returned by last_modified/1.","ref":"Liberator.Resource.html#c:unmodified_since?/1","title":"Liberator.Resource.unmodified_since?/1","type":"callback"},{"doc":"Checks the length of the URI.If this function returns true, then the plug will return a 414 URI Too Long response.By default, always returns false.","ref":"Liberator.Resource.html#c:uri_too_long?/1","title":"Liberator.Resource.uri_too_long?/1","type":"callback"},{"doc":"Check if the Content-Type of the body is valid.By default, always returns true.","ref":"Liberator.Resource.html#c:valid_content_header?/1","title":"Liberator.Resource.valid_content_header?/1","type":"callback"},{"doc":"Check if the length of the body is valid.By default, always returns true.","ref":"Liberator.Resource.html#c:valid_entity_length?/1","title":"Liberator.Resource.valid_entity_length?/1","type":"callback"},{"doc":"LiberatorAn Elixir port of the Liberator HTTP library.","ref":"readme.html","title":"Liberator","type":"extras"},{"doc":"If available in Hex, the package can be installed by adding liberator to your list of dependencies in mix.exs:def deps do [ {:liberator, &quot;~&gt; 1.0.0&quot;} ] endDocumentation can be generated with ExDoc and published on HexDocs. Once published, the docs can be found at https://hexdocs.pm/liberator.","ref":"readme.html#installation","title":"Liberator - Installation","type":"extras"}]